#pragma once

#include <cstdint>
#include <glm/glm.hpp>
#include <iostream>
#include <vector>

namespace kek {

class MemoryBuffer: public std::streambuf {

  public:
	char *buffer;
	size_t length;

	MemoryBuffer(char *buffer, size_t length) {
		this->buffer = buffer;
		this->length = length;
		this->setg(buffer, buffer, buffer + length);
	}

	~MemoryBuffer() {
		free(buffer);
	}
};

struct IntPoint2 {
	int x, y;

	IntPoint2(int x, int y)
		: x(x),
		  y(y) {}

	IntPoint2() = default;

	constexpr IntPoint2 &operator+=(const IntPoint2 &rhs) {
		this->x += rhs.x;
		this->y += rhs.y;
		return *this;
	}

	constexpr IntPoint2 &operator-=(const IntPoint2 &rhs) {
		this->x -= rhs.x;
		this->y -= rhs.y;
		return *this;
	}

	constexpr friend IntPoint2 operator+(const IntPoint2 &lhs, const IntPoint2 &rhs) {
		return IntPoint2(lhs) += rhs;
	}

	constexpr friend IntPoint2 operator-(const IntPoint2 &lhs, const IntPoint2 &rhs) {
		return IntPoint2(lhs) -= rhs;
	}
};

}
